<?php
function _setSelectionGroups(&$tof,$vars) {
	if ($vars['GroupAction']=='set')
		setSelectionGroups($tof,$vars['Groups']);
	else if ($vars['GroupAction']=='add')
		addGroupsToSelection($tof,$vars['Groups']);
	else if ($vars['GroupAction']=='remove')
		removeGroupsFromSelection($tof,$vars['Groups']);
}

function setSelectionGroups(&$tof,$groups) {
	require_once("actions/updatePictures.php");
	$selection = $tof->ct->getSelection($tof->uid);
	updatePictures($tof,"unchanged",$groups,$selection);
}

function addGroupsToSelection(&$tof,$groups) {
	require_once("actions/groups.php");
	$selection = $tof->ct->getSelection($tof->uid);
	addGroupsToPictures($tof,$groups,$selection);
}

function removeGroupsFromSelection(&$tof,$groups) {
	require_once("actions/groups.php");
	$selection = $tof->ct->getSelection($tof->uid);
	removeGroupsFromPictures($tof,$groups,$selection);
}
?>